import React from "react";
import { Redirect, Route } from "react-router-dom";
import PropTypes from "prop-types";

import { GlobalInfoStore } from "stores";

const EventBoundRoute = ({
  component: Component,
  children,
  fallbackTo = "/",
  ...rest
}) => {
  const { eventId } = GlobalInfoStore.useState();

  return (
    <Route
      {...rest}
      render={(props) =>
        !!eventId ? (
          children ? (
            children
          ) : (
            <Component {...props} />
          )
        ) : (
          <Redirect to={fallbackTo} />
        )
      }
    />
  );
};

EventBoundRoute.propTypes = {
  component: PropTypes.elementType,
  children: PropTypes.node,
  fallbackTo: PropTypes.string,
};

export default EventBoundRoute;
